@@ -2,9 +2,14 @@
 
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
+import sys
 import typing as t
 
-from typing_extensions import Protocol
+if sys.version_info >= (3, 8):
+    # pylint: disable=unused-import
+    from typing import Final, Literal, Protocol
+else:  # pragma: no cover
+    from typing_extensions import Final, Literal, Protocol
 
 _T = t.TypeVar('_T', covariant=True)
 _TT = t.TypeVar('_TT')
