@@ -25,10 +25,11 @@ class Nullable(t.Generic[_T], Parser[t.Union[_T, None]]):
         return f'Union[None, {self.__parser.describe()}]'
 
     def _to_open_api(self, schema: OpenAPISchema) -> t.Mapping[str, t.Any]:
-        return {
-            **self.__parser.to_open_api(schema),
-            'nullable': True,
-        }
+        return self.__parser.to_open_api(schema)
+
+    def to_open_api(self, schema: OpenAPISchema) -> t.Mapping[str, t.Any]:
+        res = super().to_open_api(schema)
+        return {**res, 'nullable': True}
 
     def try_parse(self, value: object) -> t.Optional[_T]:
         if value is None:
