@@ -2,20 +2,21 @@
 This module contains parsers for values that should be transformed or
 restricted in any way.
 """
-# pylint: disable=import-outside-toplevel
 import re
 import uuid
 import typing as t
 import decimal
 import datetime
-
-from typing_extensions import Final, Protocol
+# pylint: disable=import-outside-toplevel
+import fractions
 
 from cg_dt_utils import DatetimeWithTimezone
 
 from ._base import Parser, SimpleValue, SimpleParseError, SimpleValueFactory
 from ._utils import USE_SLOTS as _USE_SLOTS
 from ._utils import T as _T
+from ._utils import Final, Protocol
+from ._mapping import FixedMapping, RequiredArgument
 from .exceptions import ParseError
 from ._parse_utils import Transform as _Transform
 from ._parse_utils import Constraint as _Constraint
@@ -32,6 +33,24 @@ _GEComparableT = t.TypeVar('_GEComparableT', bound=_GEComparable)
 __all__ = ('RichValue', )
 
 
+class _NumberAsString(_Transform[int, str]):
+    def __init__(self, name: str = '_NumberAsString') -> None:
+        super().__init__(
+            SimpleValue.str,
+            self.__to_int,
+            name,
+        )
+
+    def __to_int(self, value: str) -> int:
+        try:
+            return int(value)
+        except ValueError as exc:
+            raise SimpleParseError(self, value) from exc
+
+    def _to_open_api(self, schema: t.Any) -> t.Mapping[str, t.Any]:
+        return SimpleValue.int.to_open_api(schema)
+
+
 class _UUID(_Transform[uuid.UUID, str]):
     if _USE_SLOTS:
         __slots__ = ()
@@ -58,6 +77,34 @@ class _UUID(_Transform[uuid.UUID, str]):
             ) from exc
 
 
+class _Date(_Transform[datetime.date, str]):
+    if _USE_SLOTS:
+        __slots__ = ()
+
+    _ISO8601_DATE_RE = re.compile(
+        r'^(?P<year>\d+)-(?P<month>\d\d)-(?P<day>\d\d)$'
+    )
+
+    def __init__(self) -> None:
+        super().__init__(SimpleValue.str, self.__transform_to_date, 'Date')
+
+    def _to_open_api(self, schema: OpenAPISchema) -> t.Mapping[str, t.Any]:
+        return {
+            **self._parser.to_open_api(schema),
+            'format': 'date',
+        }
+
+    def __transform_to_date(self, value: str) -> datetime.date:
+        match = self._ISO8601_DATE_RE.match(value)
+        if match is None:
+            raise SimpleParseError(self, value)
+        year, month, day = map(int, match.group('year', 'month', 'day'))
+        try:
+            return datetime.date(year=year, month=month, day=day)
+        except ValueError as exc:
+            raise SimpleParseError(self, value) from exc
+
+
 class _DateTime(_Transform[DatetimeWithTimezone, str]):
     if _USE_SLOTS:
         __slots__ = ()
@@ -192,6 +239,26 @@ class _TimeDeltaFactory(_Transform[datetime.timedelta, t.Union[str, float]]):
         )
 
 
+class _NonEmptyString(SimpleValueFactory[str]):
+    if _USE_SLOTS:
+        __slots__ = ()
+
+    def __init__(self) -> None:
+        super().__init__(str)
+
+    def try_parse(self, value: object) -> str:
+        nonempty = super().try_parse(value)
+        if not nonempty:
+            raise SimpleParseError(
+                self,
+                value,
+                extra={
+                    'message': "which is empty",
+                },
+            )
+        return nonempty
+
+
 class _StringWithoutNullByte(SimpleValueFactory[str]):
     if _USE_SLOTS:
         __slots__ = ()
@@ -203,6 +270,34 @@ class _StringWithoutNullByte(SimpleValueFactory[str]):
         return super().try_parse(value).replace('\0', '')
 
 
+class _Fraction(Parser[fractions.Fraction]):
+    if _USE_SLOTS:
+        __slots__ = ()
+
+    _SUB_PARSER = FixedMapping(
+        RequiredArgument(
+            'n',
+            _NumberAsString(),
+            'The numerator of the rational.',
+        ),
+        RequiredArgument(
+            'd',
+            _NumberAsString(),
+            'The denominator of the rational.',
+        ),
+    ).as_schema('Fraction').add_open_api_metadata('x-is-fraction', True)
+
+    def describe(self) -> str:
+        return 'Fraction'
+
+    def _to_open_api(self, schema: t.Any) -> t.Mapping[str, t.Any]:
+        return self._SUB_PARSER.to_open_api(schema)
+
+    def try_parse(self, value: object) -> fractions.Fraction:
+        data = self._SUB_PARSER.try_parse(value)
+        return fractions.Fraction(data.n, data.d)
+
+
 class _Decimal(_Transform[decimal.Decimal, str]):
     if _USE_SLOTS:
         __slots__ = ()
@@ -242,6 +337,8 @@ class RichValue:
 
     DateTime = _DateTime()
 
+    Date = _Date()
+
     EmailList = _EmailList()
 
     Password = _Password()
@@ -250,10 +347,14 @@ class RichValue:
 
     TimeDelta = _TimeDeltaFactory(SimpleValue.str | SimpleValue.float)
 
+    NonEmptyString = _NonEmptyString()
+
     StringWithoutNullByte = _StringWithoutNullByte()
 
     Decimal = _Decimal()
 
+    Fraction = _Fraction()
+
     class ValueGte(_Constraint[_GEComparableT], t.Generic[_GEComparableT]):
         """Parse a number that is gte than a given minimum.
         """
