@@ -41,6 +41,9 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
         PatchSubmitTypesAssignmentData,
     )
     from ..models.plagiarism_run import PlagiarismRun
+    from ..models.put_description_assignment_data import (
+        PutDescriptionAssignmentData,
+    )
     from ..models.put_rubric_assignment_data import PutRubricAssignmentData
     from ..models.rubric_row_base import RubricRowBase
     from ..models.update_peer_feedback_settings_assignment_data import (
@@ -274,13 +277,13 @@ class AssignmentService(t.Generic[_ClientT]):
             str, t.Union[str, bool, int, float]
         ] = None,
     ) -> "Assignment":
-        """Return the given `Assignment`.
+        """Get a single assignment by id.
 
-        :param assignment_id: The id of the assignment
+        :param assignment_id: The id of the assignment you want to get.
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: A response containing the JSON serialized assignment
+        :returns: The requested assignment.
         """
 
         url = "/api/v1/assignments/{assignmentId}".format(
@@ -410,6 +413,101 @@ class AssignmentService(t.Generic[_ClientT]):
             ),
         )
 
+    def put_description(
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
+        multipart_data: t.Union[dict, list, "PutDescriptionAssignmentData"],
+        *,
+        assignment_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "None":
+        """Stores a file containing the new description for a given
+        `Assignment`.
+
+        :param multipart_data: The data that should form the body of the
+            request. See :class:`.PutDescriptionAssignmentData` for information
+            about the possible fields.
+        :param assignment_id: The id of the assignment
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: An empty response.
+        """
+
+        url = "/api/v1/assignments/{assignmentId}/description".format(
+            assignmentId=assignment_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.put(
+                url=url,
+                files=utils.to_multipart(utils.to_dict(multipart_data)),
+                params=params,
+            )
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
+    def delete_description(
+        self: "AssignmentService[codegrade.client.AuthenticatedClient]",
+        *,
+        assignment_id: "int",
+        extra_parameters: t.Mapping[
+            str, t.Union[str, bool, int, float]
+        ] = None,
+    ) -> "None":
+        """Deletes the description for a given `Assignment`.
+
+        :param assignment_id: The id of the assignment.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: An empty response.
+        """
+
+        url = "/api/v1/assignments/{assignmentId}/description".format(
+            assignmentId=assignment_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            resp = client.http.delete(url=url, params=params)
+        utils.log_warnings(resp)
+
+        if utils.response_code_matches(resp.status_code, 204):
+            # fmt: off
+            # fmt: on
+            return parsers.ConstantlyParser(None).try_parse(resp)
+
+        from ..models.any_error import AnyError
+
+        raise utils.get_error(
+            resp,
+            (
+                (
+                    (400, 409, 401, 403, 404, "5XX"),
+                    utils.unpack_union(AnyError),
+                ),
+            ),
+        )
+
     def get_template(
         self: "AssignmentService[codegrade.client.AuthenticatedClient]",
         *,
