@@ -15,9 +15,6 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     import codegrade
 
     from ..models.assignment import Assignment
-    from ..models.bulk_course_registration_link import (
-        BulkCourseRegistrationLink,
-    )
     from ..models.bulk_enroll_course_data import BulkEnrollCourseData
     from ..models.change_user_role_course_data import ChangeUserRoleCourseData
     from ..models.course_bulk_enroll_result import CourseBulkEnrollResult
@@ -49,26 +46,14 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     from ..models.group_set import GroupSet
     from ..models.import_into_course_data import ImportIntoCourseData
     from ..models.job import Job
-    from ..models.patch_bulk_enroll_link_course_data import (
-        PatchBulkEnrollLinkCourseData,
-    )
     from ..models.patch_course_data import PatchCourseData
     from ..models.patch_role_course_data import PatchRoleCourseData
     from ..models.patch_snippet_course_data import PatchSnippetCourseData
-    from ..models.post_bulk_enroll_link_course_data import (
-        PostBulkEnrollLinkCourseData,
-    )
     from ..models.put_enroll_link_course_data import PutEnrollLinkCourseData
     from ..models.put_price_course_data import PutPriceCourseData
-    from ..models.register_user_with_bulk_link_course_data import (
-        RegisterUserWithBulkLinkCourseData,
-    )
     from ..models.register_user_with_link_course_data import (
         RegisterUserWithLinkCourseData,
     )
-    from ..models.result_data_get_course_get_personalized_registration_link import (
-        ResultDataGetCourseGetPersonalizedRegistrationLink,
-    )
     from ..models.user import User
     from ..models.user_course import UserCourse
 
@@ -366,65 +351,6 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
-    def post_bulk_enroll_link(
-        self: "CourseService[codegrade.client.AuthenticatedClient]",
-        json_body: t.Union[dict, list, "PostBulkEnrollLinkCourseData"],
-        *,
-        course_id: "int",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
-        ] = None,
-    ) -> "BulkCourseRegistrationLink":
-        """Create a bulk enroll link.
-
-        :param json_body: The body of the request. See
-            :class:`.PostBulkEnrollLinkCourseData` for information about the
-            possible fields. You can provide this data as a
-            :class:`.PostBulkEnrollLinkCourseData` or as a dictionary.
-        :param course_id: The id of the course in which this link should enroll
-            users.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: A dictionary containing the job sending out the mails and a
-                  list of user information for user incompatible with SSO
-                  courses.
-        """
-
-        url = "/api/v1/courses/{courseId}/bulk_registration_links/".format(
-            courseId=course_id
-        )
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            resp = client.http.post(
-                url=url, json=utils.to_dict(json_body), params=params
-            )
-        utils.log_warnings(resp)
-
-        if utils.response_code_matches(resp.status_code, 200):
-            # fmt: off
-            from ..models.bulk_course_registration_link import (
-                BulkCourseRegistrationLink,
-            )
-
-            # fmt: on
-            return parsers.JsonResponseParser(
-                parsers.ParserFor.make(BulkCourseRegistrationLink)
-            ).try_parse(resp)
-
-        from ..models.any_error import AnyError
-
-        raise utils.get_error(
-            resp,
-            (
-                (
-                    (400, 409, 401, 403, 404, "5XX"),
-                    utils.unpack_union(AnyError),
-                ),
-            ),
-        )
-
     def create_snippet(
         self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "CreateSnippetCourseData"],
@@ -693,7 +619,7 @@ class CourseService(t.Generic[_ClientT]):
         extra_parameters: t.Mapping[
             str, t.Union[str, bool, int, float]
         ] = None,
-    ) -> "t.Sequence[t.Union[CourseRegistrationLink, BulkCourseRegistrationLink]]":
+    ) -> "t.Sequence[CourseRegistrationLink]":
         """Get the registration links for the given course.
 
         :param course_id: The course id for which to get the registration
@@ -715,19 +641,11 @@ class CourseService(t.Generic[_ClientT]):
 
         if utils.response_code_matches(resp.status_code, 200):
             # fmt: off
-            from ..models.bulk_course_registration_link import (
-                BulkCourseRegistrationLink,
-            )
             from ..models.course_registration_link import CourseRegistrationLink
 
             # fmt: on
             return parsers.JsonResponseParser(
-                rqa.List(
-                    parsers.make_union(
-                        parsers.ParserFor.make(CourseRegistrationLink),
-                        parsers.ParserFor.make(BulkCourseRegistrationLink),
-                    )
-                )
+                rqa.List(parsers.ParserFor.make(CourseRegistrationLink))
             ).try_parse(resp)
 
         from ..models.any_error import AnyError
@@ -894,115 +812,6 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
-    def delete_bulk_enroll_link(
-        self: "CourseService[codegrade.client.AuthenticatedClient]",
-        *,
-        course_id: "int",
-        link_id: "str",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
-        ] = None,
-    ) -> "None":
-        """Delete the given bulk registration link.
-
-        :param course_id: The id of the course to which the bulk registration
-            link is connected.
-        :param link_id: The id of the bulk registration link.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: Nothing.
-        """
-
-        url = (
-            "/api/v1/courses/{courseId}/bulk_registration_links/{linkId}"
-            .format(courseId=course_id, linkId=link_id)
-        )
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            resp = client.http.delete(url=url, params=params)
-        utils.log_warnings(resp)
-
-        if utils.response_code_matches(resp.status_code, 204):
-            # fmt: off
-            # fmt: on
-            return parsers.ConstantlyParser(None).try_parse(resp)
-
-        from ..models.any_error import AnyError
-
-        raise utils.get_error(
-            resp,
-            (
-                (
-                    (400, 409, 401, 403, 404, "5XX"),
-                    utils.unpack_union(AnyError),
-                ),
-            ),
-        )
-
-    def patch_bulk_enroll_link(
-        self: "CourseService[codegrade.client.AuthenticatedClient]",
-        json_body: t.Union[dict, list, "PatchBulkEnrollLinkCourseData"],
-        *,
-        course_id: "int",
-        link_id: "str",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
-        ] = None,
-    ) -> "BulkCourseRegistrationLink":
-        """Update a bulk enroll link.
-
-        This will *not* resend any emails.
-
-        :param json_body: The body of the request. See
-            :class:`.PatchBulkEnrollLinkCourseData` for information about the
-            possible fields. You can provide this data as a
-            :class:`.PatchBulkEnrollLinkCourseData` or as a dictionary.
-        :param course_id: The id of the course in which this link should enroll
-            users.
-        :param link_id: The id of the bulk registration link.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: The updated link.
-        """
-
-        url = (
-            "/api/v1/courses/{courseId}/bulk_registration_links/{linkId}"
-            .format(courseId=course_id, linkId=link_id)
-        )
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            resp = client.http.patch(
-                url=url, json=utils.to_dict(json_body), params=params
-            )
-        utils.log_warnings(resp)
-
-        if utils.response_code_matches(resp.status_code, 200):
-            # fmt: off
-            from ..models.bulk_course_registration_link import (
-                BulkCourseRegistrationLink,
-            )
-
-            # fmt: on
-            return parsers.JsonResponseParser(
-                parsers.ParserFor.make(BulkCourseRegistrationLink)
-            ).try_parse(resp)
-
-        from ..models.any_error import AnyError
-
-        raise utils.get_error(
-            resp,
-            (
-                (
-                    (400, 409, 401, 403, 404, "5XX"),
-                    utils.unpack_union(AnyError),
-                ),
-            ),
-        )
-
     def put_price(
         self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "PutPriceCourseData"],
@@ -1852,68 +1661,6 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
-    def get_personalized_registration_link(
-        self,
-        *,
-        course_id: "int",
-        link_id: "str",
-        user_info_id: "str",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
-        ] = None,
-    ) -> "ResultDataGetCourseGetPersonalizedRegistrationLink":
-        """Get a registration link with precompiled user information for
-        sign-up.
-
-        This route can be used without logging in, i.e. you don't have to be
-        enrolled in the course to use this route. This route will not work for
-        expired registration links.
-
-        :param course_id: The id of the course to which the registration link
-            is connected.
-        :param link_id: The id of the registration link.
-        :param user_info_id: The id of the user information.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: The extended serialization of a registration link and the
-                  extended serialization of the precompiled user information.
-        """
-
-        url = "/api/v1/courses/{courseId}/registration_links/{linkId}/user_info/{userInfoId}".format(
-            courseId=course_id, linkId=link_id, userInfoId=user_info_id
-        )
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            resp = client.http.get(url=url, params=params)
-        utils.log_warnings(resp)
-
-        if utils.response_code_matches(resp.status_code, 200):
-            # fmt: off
-            from ..models.result_data_get_course_get_personalized_registration_link import (
-                ResultDataGetCourseGetPersonalizedRegistrationLink,
-            )
-
-            # fmt: on
-            return parsers.JsonResponseParser(
-                parsers.ParserFor.make(
-                    ResultDataGetCourseGetPersonalizedRegistrationLink
-                )
-            ).try_parse(resp)
-
-        from ..models.any_error import AnyError
-
-        raise utils.get_error(
-            resp,
-            (
-                (
-                    (400, 409, 401, 403, 404, "5XX"),
-                    utils.unpack_union(AnyError),
-                ),
-            ),
-        )
-
     def get_submissions_by_user(
         self: "CourseService[codegrade.client.AuthenticatedClient]",
         *,
@@ -2140,64 +1887,6 @@ class CourseService(t.Generic[_ClientT]):
             ),
         )
 
-    def register_user_with_bulk_link(
-        self,
-        json_body: t.Union[dict, list, "RegisterUserWithBulkLinkCourseData"],
-        *,
-        course_id: "int",
-        link_id: "str",
-        extra_parameters: t.Mapping[
-            str, t.Union[str, bool, int, float]
-        ] = None,
-    ) -> "CourseRegisterResponse":
-        """Register as a new user, and directly enroll in a course.
-
-        :param json_body: The body of the request. See
-            :class:`.RegisterUserWithBulkLinkCourseData` for information about
-            the possible fields. You can provide this data as a
-            :class:`.RegisterUserWithBulkLinkCourseData` or as a dictionary.
-        :param course_id: The id of the course to which the bulk registration
-            link is connected.
-        :param link_id: The id of the bulk registration link.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: The access token that the created user can use to log in.
-        """
-
-        url = (
-            "/api/v1/courses/{courseId}/bulk_registration_links/{linkId}/user"
-            .format(courseId=course_id, linkId=link_id)
-        )
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            resp = client.http.post(
-                url=url, json=utils.to_dict(json_body), params=params
-            )
-        utils.log_warnings(resp)
-
-        if utils.response_code_matches(resp.status_code, 200):
-            # fmt: off
-            from ..models.course_register_response import CourseRegisterResponse
-
-            # fmt: on
-            return parsers.JsonResponseParser(
-                parsers.ParserFor.make(CourseRegisterResponse)
-            ).try_parse(resp)
-
-        from ..models.any_error import AnyError
-
-        raise utils.get_error(
-            resp,
-            (
-                (
-                    (400, 409, 401, 403, 404, "5XX"),
-                    utils.unpack_union(AnyError),
-                ),
-            ),
-        )
-
     def email_users(
         self: "CourseService[codegrade.client.AuthenticatedClient]",
         json_body: t.Union[dict, list, "EmailUsersCourseData"],
