@@ -75,6 +75,7 @@ if t.TYPE_CHECKING or os.getenv("CG_EAGERIMPORT", False):
     from codegrade._api.user_setting import (
         UserSettingService as _UserSettingService,
     )
+    from codegrade._api.webhook import WebhookService as _WebhookService
 
 
 class _BaseClient:
@@ -109,6 +110,7 @@ class _BaseClient:
         "__transaction",
         "__user",
         "__user_setting",
+        "__webhook",
         "__open_level",
         "__http",
         "base_url",
@@ -175,6 +177,7 @@ class _BaseClient:
         self.__user_setting: t.Optional[
             "_UserSettingService[_BaseClientT]"
         ] = None
+        self.__webhook: t.Optional["_WebhookService[_BaseClientT]"] = None
         self.__http: t.Optional[httpx.Client] = None
 
     def _get_headers(self) -> t.Mapping[str, str]:
@@ -504,6 +507,15 @@ class _BaseClient:
             self.__user_setting = m.UserSettingService(self)
         return self.__user_setting
 
+    @property
+    def webhook(self: _BaseClientT) -> "_WebhookService[_BaseClientT]":
+        """Get a :class:`.WebhookService` to do requests concerning Webhook."""
+        if self.__webhook is None:
+            import codegrade._api.webhook as m
+
+            self.__webhook = m.WebhookService(self)
+        return self.__webhook
+
 
 class Client(_BaseClient):
     """A class used to do unauthenticated requests to CodeGrade"""
