@@ -286,6 +286,8 @@ from .finalized_lti1p3_provider import FinalizedLTI1p3Provider
 from .find_element_interval_setting import FindElementIntervalSetting
 from .find_element_max_tries_setting import FindElementMaxTriesSetting
 from .first_phase_lti_launch_exception import FirstPhaseLTILaunchException
+from .fixed_availability import FixedAvailability
+from .fixed_grade_availability import FixedGradeAvailability
 from .fixture_like import FixtureLike
 from .fraction import Fraction
 from .frontend_site_settings import FrontendSiteSettings
@@ -525,6 +527,9 @@ from .release_info import ReleaseInfo
 from .release_message_max_time_setting import ReleaseMessageMaxTimeSetting
 from .rename_group_group_data import RenameGroupGroupData
 from .render_html_enabled_setting import RenderHtmlEnabledSetting
+from .repository_connection_limit_reached_exception import (
+    RepositoryConnectionLimitReachedException,
+)
 from .reset_token_time_setting import ResetTokenTimeSetting
 from .result_data_get_auto_test_get import ResultDataGetAutoTestGet
 from .result_data_get_task_result_get_all import ResultDataGetTaskResultGetAll
@@ -591,6 +596,8 @@ from .tenant_statistics import TenantStatistics
 from .test_submission_copying_on_import_enabled_setting import (
     TestSubmissionCopyingOnImportEnabledSetting,
 )
+from .timed_availability import TimedAvailability
+from .token_revoked_exception import TokenRevokedException
 from .tour_configurations_setting import TourConfigurationsSetting
 from .tour_polling_interval_setting import TourPollingIntervalSetting
 from .transaction import Transaction
