@@ -586,6 +586,12 @@ class AllSiteSettings(FrontendSiteSettings):
             "CANVAS_COURSE_ID_COPYING_ENABLED": to_dict(
                 self.canvas_course_id_copying_enabled
             ),
+            "EDITOR_ENABLED_FOR_TEACHERS": to_dict(
+                self.editor_enabled_for_teachers
+            ),
+            "TEST_SUBMISSION_COPYING_ON_IMPORT_ENABLED": to_dict(
+                self.test_submission_copying_on_import_enabled
+            ),
         }
         return res
 
@@ -696,6 +702,8 @@ class AllSiteSettings(FrontendSiteSettings):
             assignment_grading_scale_points_enabled=parsed.ASSIGNMENT_GRADING_SCALE_POINTS_ENABLED,
             new_auto_test_old_submission_age=parsed.NEW_AUTO_TEST_OLD_SUBMISSION_AGE,
             canvas_course_id_copying_enabled=parsed.CANVAS_COURSE_ID_COPYING_ENABLED,
+            editor_enabled_for_teachers=parsed.EDITOR_ENABLED_FOR_TEACHERS,
+            test_submission_copying_on_import_enabled=parsed.TEST_SUBMISSION_COPYING_ON_IMPORT_ENABLED,
         )
         res.raw_data = d
         return res
