@@ -19,8 +19,11 @@ from .assignment_percentage_grading_settings import (
 )
 from .assignment_points_grading_settings import AssignmentPointsGradingSettings
 from .cg_ignore_version import CGIgnoreVersion
+from .fixed_availability import FixedAvailability
+from .fixed_grade_availability import FixedGradeAvailability
 from .group_set import GroupSet
 from .submission_validator_input_data import SubmissionValidatorInputData
+from .timed_availability import TimedAvailability
 
 
 @dataclass
@@ -32,10 +35,12 @@ class Assignment:
 
     #: The id of the assignment.
     id: "int"
-    #: Current state of the assignment.
+    #: Current state of the assignment. Deprecated: use availability and
+    #: grade\_availability fields, it will be removed in Q3 2023.
     state: "t.Literal['done', 'grading', 'hidden', 'submitting']"
     #: Description of the assignment. Deprecated, use available routes to
-    #: upload and retrieve a description file instead.
+    #: upload and retrieve a description file instead. It will be removed in Q3
+    #: 2023.
     description: "t.Optional[str]"
     #: Whether the assignment has liked description file.
     has_description: "bool"
@@ -60,7 +65,8 @@ class Assignment:
     #: The time the assignment will become available (i.e. the state will
     #: switch from 'hidden' to 'open'). If the state is not 'hidden' this value
     #: has no meaning. If this value is not `None` you cannot change to state
-    #: to 'hidden' or 'open'.
+    #: to 'hidden' or 'open'. Deprecated: use availability and
+    #: grade\_availability fields, it will be removed in Q3 2023.
     available_at: "t.Optional[datetime.datetime]"
     #: Should we send login links to all users before the `available_at` time.
     send_login_links: "bool"
@@ -129,6 +135,10 @@ class Assignment:
     #: Optionally a glob for a file that should be loaded first in the file
     #: viewer. There is no guarantee that any file actually matches this glob.
     file_to_load_first: "t.Optional[str]"
+    #: What is the availability state of this assignment.
+    availability: "t.Union[FixedAvailability, TimedAvailability]"
+    #: What is grade availability of this assignment.
+    grade_availability: "FixedGradeAvailability"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -142,7 +152,11 @@ class Assignment:
             rqa.RequiredArgument(
                 "state",
                 rqa.StringEnum("done", "grading", "hidden", "submitting"),
-                doc="Current state of the assignment.",
+                doc=(
+                    "Current state of the assignment. Deprecated: use"
+                    " availability and grade\\_availability fields, it will be"
+                    " removed in Q3 2023."
+                ),
             ),
             rqa.RequiredArgument(
                 "description",
@@ -150,7 +164,7 @@ class Assignment:
                 doc=(
                     "Description of the assignment. Deprecated, use available"
                     " routes to upload and retrieve a description file"
-                    " instead."
+                    " instead. It will be removed in Q3 2023."
                 ),
             ),
             rqa.RequiredArgument(
@@ -218,7 +232,9 @@ class Assignment:
                     " state will switch from 'hidden' to 'open'). If the state"
                     " is not 'hidden' this value has no meaning. If this value"
                     " is not `None` you cannot change to state to 'hidden' or"
-                    " 'open'."
+                    " 'open'. Deprecated: use availability and"
+                    " grade\\_availability fields, it will be removed in Q3"
+                    " 2023."
                 ),
             ),
             rqa.RequiredArgument(
@@ -404,6 +420,19 @@ class Assignment:
                     " actually matches this glob."
                 ),
             ),
+            rqa.RequiredArgument(
+                "availability",
+                parsers.make_union(
+                    parsers.ParserFor.make(FixedAvailability),
+                    parsers.ParserFor.make(TimedAvailability),
+                ),
+                doc="What is the availability state of this assignment.",
+            ),
+            rqa.RequiredArgument(
+                "grade_availability",
+                parsers.ParserFor.make(FixedGradeAvailability),
+                doc="What is grade availability of this assignment.",
+            ),
         ).use_readable_describe(True)
     )
 
@@ -446,6 +475,8 @@ class Assignment:
             "kind": to_dict(self.kind),
             "anonymized_grading": to_dict(self.anonymized_grading),
             "file_to_load_first": to_dict(self.file_to_load_first),
+            "availability": to_dict(self.availability),
+            "grade_availability": to_dict(self.grade_availability),
         }
         return res
 
@@ -491,6 +522,8 @@ class Assignment:
             kind=parsed.kind,
             anonymized_grading=parsed.anonymized_grading,
             file_to_load_first=parsed.file_to_load_first,
+            availability=parsed.availability,
+            grade_availability=parsed.grade_availability,
         )
         res.raw_data = d
         return res
