@@ -79,6 +79,7 @@ class BaseLTI1p3Provider(BaseLTIProvider):
             "created_at": to_dict(self.created_at),
             "intended_use": to_dict(self.intended_use),
             "tenant_id": to_dict(self.tenant_id),
+            "label": to_dict(self.label),
         }
         return res
 
@@ -98,6 +99,7 @@ class BaseLTI1p3Provider(BaseLTIProvider):
             created_at=parsed.created_at,
             intended_use=parsed.intended_use,
             tenant_id=parsed.tenant_id,
+            label=parsed.label,
         )
         res.raw_data = d
         return res
