@@ -17,6 +17,8 @@ class CourseOfCoursePrice:
 
     #: The id of the course that is connected to this price.
     id: "int"
+    #: The id of the tenant of the course connected to this price.
+    tenant_id: "t.Optional[str]"
     #: The name of the course that is connected to this price.
     name: "str"
 
@@ -29,6 +31,14 @@ class CourseOfCoursePrice:
                 rqa.SimpleValue.int,
                 doc="The id of the course that is connected to this price.",
             ),
+            rqa.RequiredArgument(
+                "tenant_id",
+                rqa.Nullable(rqa.SimpleValue.str),
+                doc=(
+                    "The id of the tenant of the course connected to this"
+                    " price."
+                ),
+            ),
             rqa.RequiredArgument(
                 "name",
                 rqa.SimpleValue.str,
@@ -40,6 +50,7 @@ class CourseOfCoursePrice:
     def to_dict(self) -> t.Dict[str, t.Any]:
         res: t.Dict[str, t.Any] = {
             "id": to_dict(self.id),
+            "tenant_id": to_dict(self.tenant_id),
             "name": to_dict(self.name),
         }
         return res
@@ -52,6 +63,7 @@ class CourseOfCoursePrice:
 
         res = cls(
             id=parsed.id,
+            tenant_id=parsed.tenant_id,
             name=parsed.name,
         )
         res.raw_data = d
