@@ -30,7 +30,7 @@ class CoursePermMap:
     #: Users with this permission can grade submissions.
     can_grade_work: "bool"
     #: Users with this permission can see the grade for a submission before an
-    #: assignment is set to "Done".
+    #: assignment's grades are published.
     can_see_grade_before_open: "bool"
     #: Users with this permission can see submissions of other users of this
     #: course.
@@ -38,7 +38,7 @@ class CoursePermMap:
     #: Users with this permission can view the assignments of this course.
     can_see_assignments: "bool"
     #: Users with this permission can view assignments of this course that are
-    #: set to "Hidden".
+    #: set to "Unavailable".
     can_see_hidden_assignments: "bool"
     #: Users with this permission can update the assignment info such as name,
     #: deadline and status.
@@ -139,7 +139,7 @@ class CoursePermMap:
     #: the permission to view the summary of this step
     can_view_hidden_autotest_steps: "bool"
     #: Users with this permission can view AutoTest, such as sets, before the
-    #: state of the assignment is "Done"
+    #: state of the assignment's grades are published
     can_view_autotest_before_done: "bool"
     #: Users with this permission are allowed to see the details of non hidden
     #: AutoTest steps
@@ -148,7 +148,7 @@ class CoursePermMap:
     #: fixtures
     can_view_autotest_fixture: "bool"
     #: Users with this permission can view output files created during an
-    #: AutoTest before the assignment state is "Done"
+    #: AutoTest before the assignment's grades are published
     can_view_autotest_output_files_before_done: "bool"
     #: Users with this permission can delete assignments within this course.
     can_delete_assignments: "bool"
@@ -157,10 +157,10 @@ class CoursePermMap:
     #: is in effect.
     can_override_submission_limiting: "bool"
     #: Users with this permission can see the output of linters before an
-    #: assignment is set to "Done"
+    #: assignment's grades are published
     can_see_linter_feedback_before_done: "bool"
     #: Users with this permission can see all inline and general feedback,
-    #: except for peer feedback, before an assignment is set to "Done"
+    #: except for peer feedback, before an assignment's grades are published
     can_see_user_feedback_before_done: "bool"
     #: Users with this permission can view the analytics dashboard of an
     #: assignment.
@@ -210,7 +210,7 @@ class CoursePermMap:
     #: date of an assignment.
     can_upload_after_lock_date: "bool"
     #: Users with this permission are allowed to see inline and general peer
-    #: feedback before the state of an assignment has been set to "Done".
+    #: feedback before the state of an assignment's grades are published.
     can_see_peer_feedback_before_done: "bool"
     #: Users with this permission can see the real name of students even when
     #: anonymized grading is enabled.
@@ -315,7 +315,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can see the grade for a"
-                    ' submission before an assignment is set to "Done".'
+                    " submission before an assignment's grades are published."
                 ),
             ),
             rqa.RequiredArgument(
@@ -339,7 +339,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can view assignments of this"
-                    ' course that are set to "Hidden".'
+                    ' course that are set to "Unavailable".'
                 ),
             ),
             rqa.RequiredArgument(
@@ -619,7 +619,8 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can view AutoTest, such as"
-                    ' sets, before the state of the assignment is "Done"'
+                    " sets, before the state of the assignment's grades are"
+                    " published"
                 ),
             ),
             rqa.RequiredArgument(
@@ -643,7 +644,8 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can view output files created"
-                    ' during an AutoTest before the assignment state is "Done"'
+                    " during an AutoTest before the assignment's grades are"
+                    " published"
                 ),
             ),
             rqa.RequiredArgument(
@@ -668,7 +670,7 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can see the output of linters"
-                    ' before an assignment is set to "Done"'
+                    " before an assignment's grades are published"
                 ),
             ),
             rqa.RequiredArgument(
@@ -676,8 +678,8 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission can see all inline and general"
-                    " feedback, except for peer feedback, before an assignment"
-                    ' is set to "Done"'
+                    " feedback, except for peer feedback, before an"
+                    " assignment's grades are published"
                 ),
             ),
             rqa.RequiredArgument(
@@ -808,8 +810,8 @@ class CoursePermMap:
                 rqa.SimpleValue.bool,
                 doc=(
                     "Users with this permission are allowed to see inline and"
-                    " general peer feedback before the state of an assignment"
-                    ' has been set to "Done".'
+                    " general peer feedback before the state of an"
+                    " assignment's grades are published."
                 ),
             ),
             rqa.RequiredArgument(
