@@ -74,6 +74,9 @@ class GlobalPermMap:
     #: Users with this permission have all other permissions in all tenants and
     #: courses, even when they do not have a role within the tenant or course
     is_admin: "bool"
+    #: Determines whether the user will see announcement reserved for non
+    #: student users in the announcement center within the sidebar
+    can_see_teacher_announcements: "bool"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -259,6 +262,15 @@ class GlobalPermMap:
                     " role within the tenant or course"
                 ),
             ),
+            rqa.RequiredArgument(
+                "can_see_teacher_announcements",
+                rqa.SimpleValue.bool,
+                doc=(
+                    "Determines whether the user will see announcement"
+                    " reserved for non student users in the announcement"
+                    " center within the sidebar"
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -297,6 +309,9 @@ class GlobalPermMap:
                 self.can_view_not_started_autotest_results
             ),
             "is_admin": to_dict(self.is_admin),
+            "can_see_teacher_announcements": to_dict(
+                self.can_see_teacher_announcements
+            ),
         }
         return res
 
@@ -330,6 +345,7 @@ class GlobalPermMap:
             can_see_coupons=parsed.can_see_coupons,
             can_view_not_started_autotest_results=parsed.can_view_not_started_autotest_results,
             is_admin=parsed.is_admin,
+            can_see_teacher_announcements=parsed.can_see_teacher_announcements,
         )
         res.raw_data = d
         return res
