@@ -11,11 +11,13 @@ from httpx import Response
 
 from .. import parsers
 from ..utils import to_dict
-from .base_error import BaseError
+from .auto_test_step_validation_exception import (
+    AutoTestStepValidationException,
+)
 
 
 @dataclass
-class InvalidIOCasesException(BaseError):
+class InvalidIOCasesException(AutoTestStepValidationException):
     """The exception raised when an IO test contained invalid data."""
 
     #: The list of invalid cases. Each case is a two tuple of an int and a
@@ -26,7 +28,7 @@ class InvalidIOCasesException(BaseError):
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
     data_parser: t.ClassVar = rqa.Lazy(
-        lambda: BaseError.data_parser.parser.combine(
+        lambda: AutoTestStepValidationException.data_parser.parser.combine(
             rqa.FixedMapping(
                 rqa.RequiredArgument(
                     "invalid_cases",
@@ -51,6 +53,7 @@ class InvalidIOCasesException(BaseError):
     def to_dict(self) -> t.Dict[str, t.Any]:
         res: t.Dict[str, t.Any] = {
             "invalid_cases": to_dict(self.invalid_cases),
+            "step_idx": to_dict(self.step_idx),
             "message": to_dict(self.message),
             "description": to_dict(self.description),
             "code": to_dict(self.code),
@@ -68,6 +71,7 @@ class InvalidIOCasesException(BaseError):
 
         res = cls(
             invalid_cases=parsed.invalid_cases,
+            step_idx=parsed.step_idx,
             message=parsed.message,
             description=parsed.description,
             code=parsed.code,
@@ -83,5 +87,6 @@ import os
 if os.getenv("CG_GENERATING_DOCS", "False").lower() in ("", "true"):
     # fmt: off
     from .api_codes import APICodes
+    from .base_error import BaseError
 
     # fmt: on
