@@ -21,14 +21,18 @@ from .assignment_percentage_grading_settings import (
 )
 from .assignment_points_grading_settings import AssignmentPointsGradingSettings
 from .assignment_state_enum import AssignmentStateEnum
+from .fixed_availability import FixedAvailability
+from .fixed_grade_availability import FixedGradeAvailability
 from .submission_validator_input_data import SubmissionValidatorInputData
+from .timed_availability import TimedAvailability
 
 
 @dataclass
 class PatchAssignmentData:
     """Input data required for the `Assignment::Patch` operation."""
 
-    #: The new state of the assignment
+    #: The new state of the assignment. Deprecated, use the "availability" and
+    #: "grade\_availability" options, will be removed in Q3 2023.
     state: Maybe["AssignmentStateEnum"] = Nothing
     #: The new name of the assignment
     name: Maybe["str"] = Nothing
@@ -42,10 +46,11 @@ class PatchAssignmentData:
     #: The group set id for this assignment. Set to `null` to make this
     #: assignment not a group assignment
     group_set_id: Maybe["t.Optional[int]"] = Nothing
-    #: The time the assignment should become available
+    #: The time the assignment should become available. Deprecated, use the
+    #: "availability" option, will be removed in Q3 2023.
     available_at: Maybe["t.Optional[datetime.datetime]"] = Nothing
     #: Should we send login links to students before the assignment opens. This
-    #: is only available for assignments with 'kind' equal to 'exam'
+    #: is only available for assignments with 'kind' equal to 'exam'.
     send_login_links: Maybe["bool"] = Nothing
     #: The new kind of assignment
     kind: Maybe["AssignmentKind"] = Nothing
@@ -88,6 +93,12 @@ class PatchAssignmentData:
         "t.Union[AssignmentPointsGradingSettings,"
         " AssignmentPercentageGradingSettings]"
     ] = Nothing
+    #: The availability of this assignment.
+    availability: Maybe[
+        "t.Union[FixedAvailability, TimedAvailability]"
+    ] = Nothing
+    #: The grade availability of this assignment.
+    grade_availability: Maybe["FixedGradeAvailability"] = Nothing
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -96,7 +107,11 @@ class PatchAssignmentData:
             rqa.OptionalArgument(
                 "state",
                 rqa.EnumValue(AssignmentStateEnum),
-                doc="The new state of the assignment",
+                doc=(
+                    "The new state of the assignment. Deprecated, use the"
+                    ' "availability" and "grade\\_availability" options, will'
+                    " be removed in Q3 2023."
+                ),
             ),
             rqa.OptionalArgument(
                 "name",
@@ -132,7 +147,11 @@ class PatchAssignmentData:
             rqa.OptionalArgument(
                 "available_at",
                 rqa.Nullable(rqa.RichValue.DateTime),
-                doc="The time the assignment should become available",
+                doc=(
+                    "The time the assignment should become available."
+                    ' Deprecated, use the "availability" option, will be'
+                    " removed in Q3 2023."
+                ),
             ),
             rqa.OptionalArgument(
                 "send_login_links",
@@ -140,7 +159,7 @@ class PatchAssignmentData:
                 doc=(
                     "Should we send login links to students before the"
                     " assignment opens. This is only available for assignments"
-                    " with 'kind' equal to 'exam'"
+                    " with 'kind' equal to 'exam'."
                 ),
             ),
             rqa.OptionalArgument(
@@ -254,6 +273,19 @@ class PatchAssignmentData:
                 ),
                 doc="Grading settings of this assignment.",
             ),
+            rqa.OptionalArgument(
+                "availability",
+                parsers.make_union(
+                    parsers.ParserFor.make(FixedAvailability),
+                    parsers.ParserFor.make(TimedAvailability),
+                ),
+                doc="The availability of this assignment.",
+            ),
+            rqa.OptionalArgument(
+                "grade_availability",
+                parsers.ParserFor.make(FixedGradeAvailability),
+                doc="The grade availability of this assignment.",
+            ),
         ).use_readable_describe(True)
     )
 
@@ -287,6 +319,8 @@ class PatchAssignmentData:
         self.anonymized_grading = maybe_from_nullable(self.anonymized_grading)
         self.file_to_load_first = maybe_from_nullable(self.file_to_load_first)
         self.grading = maybe_from_nullable(self.grading)
+        self.availability = maybe_from_nullable(self.availability)
+        self.grade_availability = maybe_from_nullable(self.grade_availability)
 
     def to_dict(self) -> t.Dict[str, t.Any]:
         res: t.Dict[str, t.Any] = {}
@@ -340,6 +374,10 @@ class PatchAssignmentData:
             res["file_to_load_first"] = to_dict(self.file_to_load_first.value)
         if self.grading.is_just:
             res["grading"] = to_dict(self.grading.value)
+        if self.availability.is_just:
+            res["availability"] = to_dict(self.availability.value)
+        if self.grade_availability.is_just:
+            res["grade_availability"] = to_dict(self.grade_availability.value)
         return res
 
     @classmethod
@@ -371,6 +409,8 @@ class PatchAssignmentData:
             anonymized_grading=parsed.anonymized_grading,
             file_to_load_first=parsed.file_to_load_first,
             grading=parsed.grading,
+            availability=parsed.availability,
+            grade_availability=parsed.grade_availability,
         )
         res.raw_data = d
         return res
