@@ -3,6 +3,8 @@
 SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
 """
 import datetime
+import decimal
+import fractions
 import io
 import json
 import math
@@ -82,6 +84,14 @@ def to_dict(obj: t.Any) -> t.Any:
     elif isinstance(obj, datetime.timedelta):
         return obj.total_seconds()
 
+    if isinstance(obj, fractions.Fraction):
+        n, d = obj.as_integer_ratio()
+        res: t.Dict[str, t.Any] = {
+            "n": str(n),
+            "d": str(d),
+        }
+        return res
+
     from .models.types import File
 
     if isinstance(obj, File):
@@ -89,8 +99,6 @@ def to_dict(obj: t.Any) -> t.Any:
     elif hasattr(obj, "to_dict"):
         return obj.to_dict()
 
-    import decimal
-
     if isinstance(obj, decimal.Decimal):
         return str(obj)
 
